<template>
    <div class="w-100">

        <address-form
          editmode="true"
          @closeDialog="closeDialog"
          v-if="edit_address"
          :addnew="edit_address"
          :address="address_data"
          :address_list="address_list"
          type="delivery"
          :order="null"
          address_label="Edit Address"
          :show_invoice_notice="false"
        ></address-form>

        <address-form
          v-if="add_address"
          address_label="Add New Address"
          :show_invoice_notice="false"
          :order="null"
          :addnew="add_address"
          :address="address_data"
          :address_list="address_list"
          type="delivery"
          @closeDialog="closeDialog"
        ></address-form>

        <v-card md12 v-if="!mainloading">

            <v-card-title>
                <v-flex align-center justify-space-between>
                    <h2>Addresses</h2>
                    <v-btn
                        color="primary"
                        @click="addAddress">
                        add new address
                    </v-btn>
                </v-flex>
            </v-card-title>
            <v-divider></v-divider>
            <v-card-text v-if="Object.keys(addresses).length">
                <v-layout row wrap mb-0>
                    <v-flex md4 sm6 xs12 class="relative _address_card"  v-for="address in addresses" :key="address.id_address">
                        <div class="_address_card_content">
                            <div class="_address text-capitalize">
                                <h3 class="mb-2"> <span>{{ address.firstname }} {{ address.lastname }}</span> </h3>
                                <p>
                                    <span v-if="address.company && address.company != 'null'"> {{ address.company }} <br></span>
                                    {{ address.address1 }}
                                    <span class="text-normal" v-if="address.address2 && address.address2 != 'null'">, {{ address.address2 }} </span>
                                    <br>{{ address.city }}, {{ address.name }} {{ address.postcode }}<br>
                                    United States
                                </p>
                            </div>
                            <div class="_actions mt-3">
                                <v-btn
                                    small
                                    @click="editAddress(address.id_address)"
                                    color="secondary"
                                    depressed
                                    class="ml-0"
                                 >Edit</v-btn>
                                <v-btn
                                    color="error"
                                    small
                                    @click="deleteAddress(address.id_address)"
                                    flat    
                                >Delete</v-btn>
                            </div>
                        </div>
                    </v-flex>
                </v-layout>
            </v-card-text>
            <v-card-text v-else>
                <v-alert type="error" :value="true" outline>
                    No Addresses found yet
                </v-alert>
            </v-card-text>

        </v-card>
        <v-card class="w-100 _progress" v-else>
            <v-progress-circular
                :width="2"
                :size="50"
                color="#525252"
                indeterminate
            ></v-progress-circular>
            <span>Loading addresses</span>
        </v-card>
    </div>
</template>
<script>
import axios from 'axios';
import Vue from 'vue';
import AddressForm from '~/components/AddressForm.vue';

Vue.component('address-form', AddressForm);

export default {
    layout: 'customer',
    data () {
        return {
            address_list: this,
            addresses: [],
            address_data: [],
            loading: false,
            mainloading: true,
            edit_address: false,
            add_address: false,
        }
    },
    methods: {
        closeDialog (data) {
          this.mainloading = false;
          this.add_address = false;
          this.edit_address = false;

          if (data && data.fetchAddresses) {
            this.getAddresses();
          }

        },
        editAddress: function(id_address) {
            this.mainloading = true;
            var form_data = new FormData();
            form_data.append('id', id_address);
            axios.post(this.$store.state.api_domain + "?comp=process&action=getAddressById", form_data, {
            withCredentials:true
            }).then((res) => {
                if (res.data.status == 'success') {
                    this.address_data = res.data.address;
                    this.edit_address = true;
                    this.getAddresses();
                }
                this.mainloading = false;
            });
        },
        deleteAddress: function(id_address) {
            this.mainloading = true;
            var form_data = new FormData();
            form_data.append('id', id_address);
            axios.post(this.$store.state.api_domain + "?comp=process&action=deleteAddressById", form_data, {
                withCredentials: true
            }).then((res) => {
                this.$store.commit('showSnackBar', res.data.message);
                this.mainloading = false;
                this.getAddresses();
            });
        },
        addAddress: function() {
            this.mainloading = true;
            this.add_address = true;
        },
        getAddresses: function() {
            this.mainloading = true;
            axios.get(this.$store.state.api_domain + '?comp=process&action=getAddresses', {
                withCredentials: true
                }).then((res) => {
                    this.mainloading = false;
                    this.addresses = res.data;
                });
        }
    },
    created () {
        this.getAddresses();
    },
    head () {
      return {
        title: 'Addresses | Account | Balingwiredirect.com',
        meta: [
          { hid: 'description', name: 'description', content: 'All addresses' },
          { hid: 'keywords', name: 'keywords',  content: 'addresses' }
        ]
      }
    }
}
</script>
